==> pentobi_18.3.orig.tar.xz: pentobi-18.3/pentobi_thumbnailer/i18n/ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>main</name>
    <message>
        <source>thumbnailer for Blokus game records as used by Pentobi</source>
        <translation>эскиз для записей игр Блокус, используемый Pentobi</translation>
    </message>
    <message>
        <source>Generate image with height and width &lt;size&gt;.</source>
        <extracomment>Description for command line option --size</extracomment>
        <translation>Создать изображение с высотой и шириной &lt;size&gt;.</translation>
    </message>
    <message>
        <source>size</source>
        <extracomment>Value name for command line option --size</extracomment>
        <translation>размер</translation>
    </message>
    <message>
        <source>input.blksgf</source>
        <extracomment>Name of input file command line argument.</extracomment>
        <translation>входной.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF input file.</source>
        <translation>Входной файл Blokus SGF.</translation>
    </message>
    <message>
        <source>output.png</source>
        <extracomment>Name of output image file command line argument.</extracomment>
        <translation>выходной.png</translation>
    </message>
    <message>
        <source>PNG image output file.</source>
        <translation>Выходной файл изображения PNG.</translation>
    </message>
    <message>
        <source>Invalid image size</source>
        <translation>Неверный размер изображения</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>Слишком много аргументов</translation>
    </message>
    <message>
        <source>Need input and output file argument</source>
        <translation>Нужен аргумент входного и выходного файлов</translation>
    </message>
    <message>
        <source>Thumbnail creation failed</source>
        <translation>Не удалось создать миниатюру</translation>
    </message>
</context>
</TS>

==> pentobi_23.1.orig.tar.xz: pentobi-23.1/pentobi_thumbnailer/i18n/ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>main</name>
    <message>
        <source>thumbnailer for Blokus game records as used by Pentobi</source>
        <translation>эскиз для записей игр Блокус, используемый Pentobi</translation>
    </message>
    <message>
        <source>Generate image with height and width &lt;size&gt;.</source>
        <extracomment>Description for command line option --size</extracomment>
        <translation>Создать изображение с высотой и шириной &lt;size&gt;.</translation>
    </message>
    <message>
        <source>size</source>
        <extracomment>Value name for command line option --size</extracomment>
        <translation>размер</translation>
    </message>
    <message>
        <source>input.blksgf</source>
        <extracomment>Name of input file command line argument.</extracomment>
        <translation>входной.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF input file.</source>
        <translation>Входной файл Blokus SGF.</translation>
    </message>
    <message>
        <source>output.png</source>
        <extracomment>Name of output image file command line argument.</extracomment>
        <translation>выходной.png</translation>
    </message>
    <message>
        <source>PNG image output file.</source>
        <translation>Выходной файл изображения PNG.</translation>
    </message>
    <message>
        <source>Invalid image size</source>
        <translation>Неверный размер изображения</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>Слишком много аргументов</translation>
    </message>
    <message>
        <source>Need input and output file argument</source>
        <translation>Нужен аргумент входного и выходного файлов</translation>
    </message>
    <message>
        <source>Thumbnail creation failed</source>
        <translation>Не удалось создать миниатюру</translation>
    </message>
</context>
</TS>
